@@ -1,7 +1,7 @@
 package File::Write::Rotate;
 
-our $DATE = '2015-01-26'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $DATE = '2016-06-06'; # DATE
+our $VERSION = '0.30'; # VERSION
 
 use 5.010001;
 use strict;
@@ -14,7 +14,7 @@ use Carp;
 use File::Spec;
 use IO::Compress::Gzip qw(gzip $GzipError);
 use Scalar::Util qw(weaken);
-use Taint::Runtime qw(untaint is_tainted);
+#use Taint::Runtime qw(untaint is_tainted);
 use Time::HiRes 'time';
 
 our $Debug;
@@ -225,7 +225,8 @@ sub _rotate_and_delete {
 
             # TODO actually, it's more proper to taint near the source (in this
             # case, _get_files)
-            untaint \$orig;
+            #untaint \$orig;
+            ($orig) = $orig =~ /(.*)/s; # we use this instead, no module needed
 
             if ($i <= @$files - $self->{histories}) {
                 say "DEBUG: Deleting old rotated file $dir/$orig$cs ..."
@@ -366,9 +367,7 @@ sub write {
         $self->{hook_before_write}->($self, \@msg, $self->{_fh})
             if $self->{hook_before_write};
 
-        # syntax limitation? can't do print $self->{_fh} ... directly
-        my $fh = $self->{_fh};
-        print $fh @msg;
+        print { $self->{_fh} } @msg;
         $self->{_buffer} = [];
 
     };
@@ -387,7 +386,7 @@ sub write {
                 (
                     @{ $self->{_buffer} }
                     ? " (buffer is full, "
-                      . ~~@{ $self->{_buffer} }
+                      . scalar(@{ $self->{_buffer} })
                       . " message(s))"
                     : ""
                 ),
@@ -467,7 +466,7 @@ File::Write::Rotate - Write to files that archive/rotate themselves
 
 =head1 VERSION
 
-This document describes version 0.28 of File::Write::Rotate (from Perl distribution File-Write-Rotate), released on 2015-01-26.
+This document describes version 0.30 of File::Write::Rotate (from Perl distribution File-Write-Rotate), released on 2016-06-06.
 
 =head1 SYNOPSIS
 
@@ -752,6 +751,22 @@ file sizes will exceed for a bit if you do size-based rotation. More suitable if
 you only do size-based rotation since it is usually okay to exceed sizes for a
 bit.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/File-Write-Rotate>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-File-Write-Rotate>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Write-Rotate>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 SEE ALSO
 
 L<Log::Dispatch::FileRotate>, which inspires this module. Differences between
@@ -790,29 +805,13 @@ slightly faster than LDFR on my testing).
 L<Tie::Handle::FileWriteRotate> and Log::Dispatch::FileWriteRotate, which use
 this module.
 
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/File-Write-Rotate>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/perlancar/perl-File-Write-Rotate>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Write-Rotate>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
